@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 from datetime import date
-from workalendar.core import WesternCalendar, ChristianMixin
-from workalendar.registry import iso_register
+from ..core import WesternCalendar, ChristianMixin
+from ..registry_tools import iso_register
 
 
 @iso_register('PT')
@@ -22,16 +20,15 @@ class Portugal(WesternCalendar, ChristianMixin):
     )
 
     def get_fixed_holidays(self, year):
-        days = super(Portugal, self).get_fixed_holidays(year)
+        days = super().get_fixed_holidays(year)
         if year > 2015 or year < 2013:
-
             days.append((date(year, 10, 5), "Implantação da República"))
             days.append((date(year, 11, 1), "Todos os santos"))
             days.append((date(year, 12, 1), "Restauração da Independência"))
         return days
 
     def get_variable_days(self, year):
-        days = super(Portugal, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         if year > 2015 or year < 2013:
             days.append((self.get_corpus_christi(year), "Corpus Christi"))
         return days
