@@ -1,47 +1,46 @@
-# coding=utf-8
 from datetime import date
 from collections import Counter
 
-from workalendar.tests import GenericCalendarTest
-from workalendar.europe import Austria
-from workalendar.europe import Bulgaria
-from workalendar.europe import Belgium
-from workalendar.europe import Croatia
-from workalendar.europe import Cyprus
-from workalendar.europe import CzechRepublic
-from workalendar.europe import Denmark
-from workalendar.europe import Slovakia
-from workalendar.europe import Finland
-from workalendar.europe import Estonia
-from workalendar.europe import Sweden
-from workalendar.europe import France, FranceAlsaceMoselle
-from workalendar.europe import Greece
-from workalendar.europe import Hungary
-from workalendar.europe import Iceland
-from workalendar.europe import Ireland
-from workalendar.europe import Italy
-from workalendar.europe import Latvia
-from workalendar.europe import Lithuania
-from workalendar.europe import Luxembourg
-from workalendar.europe import Malta
-from workalendar.europe import Netherlands
-from workalendar.europe import Norway
-from workalendar.europe import Poland
-from workalendar.europe import Portugal
-from workalendar.europe import Romania
-from workalendar.europe import Russia
-from workalendar.europe import Spain, Catalonia
-from workalendar.europe import Slovenia
-from workalendar.europe import Switzerland, Vaud
-from workalendar.europe import UnitedKingdom
-from workalendar.europe import UnitedKingdomNorthernIreland
-from workalendar.europe import EuropeanCentralBank
-from workalendar.europe import (Germany, BadenWurttemberg, Bavaria, Berlin,
-                                Brandenburg, Bremen, Hamburg, Hesse,
-                                MecklenburgVorpommern, LowerSaxony,
-                                NorthRhineWestphalia, RhinelandPalatinate,
-                                Saarland, Saxony, SaxonyAnhalt,
-                                SchleswigHolstein, Thuringia)
+from . import GenericCalendarTest
+from ..europe import (
+    Austria,
+    Bulgaria,
+    Belarus,
+    Belgium,
+    CaymanIslands,
+    Croatia,
+    Cyprus,
+    CzechRepublic,
+    Denmark,
+    Slovakia,
+    Finland,
+    Estonia,
+    Sweden,
+    France, FranceAlsaceMoselle,
+    Greece,
+    Hungary,
+    Iceland,
+    Ireland,
+    Italy,
+    Latvia,
+    Lithuania,
+    Luxembourg,
+    Malta,
+    Netherlands,
+    Norway,
+    Poland,
+    Portugal,
+    Romania,
+    Russia,
+    Serbia,
+    Spain, Catalonia,
+    Slovenia,
+    Switzerland, Vaud, Geneva,
+    Ukraine,
+    UnitedKingdom,
+    UnitedKingdomNorthernIreland,
+    EuropeanCentralBank,
+)
 
 
 class AustriaTest(GenericCalendarTest):
@@ -64,6 +63,38 @@ class AustriaTest(GenericCalendarTest):
         self.assertIn(date(2016, 12, 26), holidays)  # St Stephens
 
 
+class BelarusTest(GenericCalendarTest):
+    cal_class = Belarus
+
+    def test_year_2019(self):
+        holidays = self.cal.holidays_set(2019)
+        self.assertIn(date(2019, 1, 1), holidays)  # New Years day
+        self.assertIn(date(2019, 1, 2), holidays)  # Day after NYE
+        self.assertIn(date(2019, 1, 7), holidays)  # Christmas (Orthodox)
+        self.assertIn(date(2019, 3, 8), holidays)  # International Women's Day
+        self.assertIn(date(2019, 5, 1), holidays)  # Labour Day
+        self.assertIn(date(2019, 5, 6), holidays)  # Radonista
+        self.assertIn(date(2019, 5, 7), holidays)  # Radonista Holiday
+        self.assertIn(date(2019, 5, 9), holidays)  # Victory Day
+        self.assertIn(date(2019, 7, 3), holidays)  # Republic Day
+        self.assertIn(date(2019, 11, 7), holidays)  # October Revolution Day
+        self.assertIn(date(2019, 12, 25), holidays)  # Christmas (Catholic)
+
+    def test_year_2020(self):
+        holidays = self.cal.holidays_set(2020)
+        self.assertIn(date(2020, 1, 1), holidays)  # New Years day
+        self.assertIn(date(2020, 1, 2), holidays)  # Day after NYE
+        self.assertIn(date(2020, 1, 7), holidays)  # Christmas (Orthodox)
+        self.assertIn(date(2020, 3, 8), holidays)  # International Women's Day
+        self.assertIn(date(2020, 4, 27), holidays)  # Radonista
+        self.assertIn(date(2020, 4, 28), holidays)  # Radonista Holiday
+        self.assertIn(date(2020, 5, 1), holidays)  # Labour Day
+        self.assertIn(date(2020, 5, 9), holidays)  # Victory Day
+        self.assertIn(date(2020, 7, 3), holidays)  # Republic Day
+        self.assertIn(date(2020, 11, 7), holidays)  # October Revolution Day
+        self.assertIn(date(2020, 12, 25), holidays)  # Christmas (Catholic)
+
+
 class BulgariaTest(GenericCalendarTest):
     cal_class = Bulgaria
 
@@ -85,6 +116,125 @@ class BulgariaTest(GenericCalendarTest):
         self.assertNotIn(date(2016, 11, 1), holidays)   # National Awakening
 
 
+class CaymanIslandsTest(GenericCalendarTest):
+    cal_class = CaymanIslands
+
+    def test_holidays_2013(self):
+        holidays = self.cal.holidays_set(2013)
+        self.assertIn(date(2013, 1, 1), holidays)
+        self.assertIn(date(2013, 1, 28), holidays)  # National Heroes Day
+        self.assertIn(date(2013, 2, 13), holidays)   # Ash Wednesday
+        self.assertIn(date(2013, 3, 29), holidays)  # good friday
+        self.assertIn(date(2013, 4, 1), holidays)  # easter monday
+        self.assertIn(date(2013, 5, 20), holidays)  # Discovery Day
+        self.assertIn(date(2013, 6, 17), holidays)  # Queen's Birthday
+        self.assertIn(date(2013, 7, 1), holidays)   # Constitution Day
+        self.assertIn(date(2013, 11, 11), holidays)  # Remembrance Day
+        self.assertIn(date(2013, 12, 25), holidays)  # XMas
+        self.assertIn(date(2013, 12, 26), holidays)  # Boxing Day
+
+    def test_holidays_2014(self):
+        holidays = self.cal.holidays_set(2014)
+        self.assertIn(date(2014, 1, 1), holidays)
+        self.assertIn(date(2014, 1, 27), holidays)  # National Heroes Day
+        self.assertIn(date(2014, 3, 5), holidays)   # Ash Wednesday
+        self.assertIn(date(2014, 4, 18), holidays)  # good friday
+        self.assertIn(date(2014, 4, 21), holidays)  # easter monday
+        self.assertIn(date(2014, 5, 19), holidays)  # Discovery Day
+        self.assertIn(date(2014, 6, 16), holidays)  # Queen's Birthday
+        self.assertIn(date(2014, 7, 7), holidays)   # Constitution Day
+        self.assertIn(date(2014, 11, 10), holidays)  # Remembrance Day
+        self.assertIn(date(2014, 12, 25), holidays)  # XMas
+        self.assertIn(date(2014, 12, 26), holidays)  # Boxing Day (on week-end)
+
+    def test_holidays_2015(self):
+        holidays = self.cal.holidays_set(2015)
+        self.assertIn(date(2015, 1, 1), holidays)
+        self.assertIn(date(2015, 1, 26), holidays)  # National Heroes Day
+        self.assertIn(date(2015, 2, 18), holidays)   # Ash Wednesday
+        self.assertIn(date(2015, 4, 3), holidays)  # good friday
+        self.assertIn(date(2015, 4, 6), holidays)  # easter monday
+        self.assertIn(date(2015, 5, 18), holidays)  # Discovery Day
+        self.assertIn(date(2015, 6, 15), holidays)  # Queen's Birthday
+        self.assertIn(date(2015, 7, 6), holidays)   # Constitution Day
+        self.assertIn(date(2015, 11, 9), holidays)  # Remembrance Day
+        self.assertIn(date(2015, 12, 25), holidays)  # XMas
+        self.assertIn(date(2015, 12, 26), holidays)  # Boxing Day (on week-end)
+        self.assertIn(date(2015, 12, 28), holidays)  # Boxing Day observed
+
+    def test_holidays_2016(self):
+        holidays = self.cal.holidays_set(2016)
+        self.assertIn(date(2016, 1, 1), holidays)
+        self.assertIn(date(2016, 1, 25), holidays)  # National Heroes Day
+        self.assertIn(date(2016, 2, 10), holidays)   # Ash Wednesday
+        self.assertIn(date(2016, 3, 25), holidays)  # good friday
+        self.assertIn(date(2016, 3, 28), holidays)  # easter monday
+        self.assertIn(date(2016, 5, 16), holidays)  # Discovery Day
+        self.assertIn(date(2016, 6, 13), holidays)  # Queen's Birthday
+        self.assertIn(date(2016, 7, 4), holidays)   # Constitution Day
+        self.assertIn(date(2016, 11, 14), holidays)  # Remembrance Day
+        self.assertIn(date(2016, 12, 26), holidays)  # XMas (in lieu)
+        self.assertIn(date(2016, 12, 27), holidays)  # Boxing Day (in lieu)
+
+    def test_holidays_2017(self):
+        holidays = self.cal.holidays_set(2017)
+        self.assertIn(date(2017, 1, 1), holidays)
+        self.assertIn(date(2017, 1, 2), holidays)  # New Year boxing
+        self.assertIn(date(2017, 1, 23), holidays)  # National Heroes Day
+        self.assertIn(date(2017, 3, 1), holidays)   # Ash Wednesday
+        self.assertIn(date(2017, 4, 14), holidays)  # good friday
+        self.assertIn(date(2017, 4, 17), holidays)  # easter monday
+        self.assertIn(date(2017, 5, 15), holidays)  # Discovery Day
+        self.assertIn(date(2017, 5, 24), holidays)  # Election Day
+        self.assertIn(date(2017, 6, 19), holidays)  # Queen's Birthday
+        self.assertIn(date(2017, 7, 3), holidays)   # Constitution Day
+        self.assertIn(date(2017, 11, 13), holidays)  # Remembrance Day
+        self.assertIn(date(2017, 12, 25), holidays)  # XMas
+        self.assertIn(date(2017, 12, 26), holidays)  # Boxing Day
+
+    def test_holidays_2018(self):
+        holidays = self.cal.holidays_set(2018)
+        self.assertIn(date(2018, 1, 1), holidays)
+        self.assertIn(date(2018, 1, 22), holidays)  # National Heroes Day
+        self.assertIn(date(2018, 2, 14), holidays)   # Ash Wednesday
+        self.assertIn(date(2018, 3, 30), holidays)  # good friday
+        self.assertIn(date(2018, 4, 2), holidays)  # easter monday
+        self.assertIn(date(2018, 5, 21), holidays)  # Discovery Day
+        self.assertIn(date(2018, 6, 11), holidays)  # Queen's Birthday
+        self.assertIn(date(2018, 7, 2), holidays)   # Constitution Day
+        self.assertIn(date(2018, 11, 12), holidays)  # Remembrance Day
+        self.assertIn(date(2018, 12, 25), holidays)  # XMas
+        self.assertIn(date(2018, 12, 26), holidays)  # Boxing Day
+
+    def test_holidays_2019(self):
+        holidays = self.cal.holidays_set(2019)
+        self.assertIn(date(2019, 1, 1), holidays)
+        self.assertIn(date(2019, 1, 28), holidays)  # National Heroes Day
+        self.assertIn(date(2019, 3, 6), holidays)   # Ash Wednesday
+        self.assertIn(date(2019, 4, 19), holidays)  # good friday
+        self.assertIn(date(2019, 4, 22), holidays)  # easter monday
+        self.assertIn(date(2019, 5, 20), holidays)  # Discovery Day
+        self.assertIn(date(2019, 6, 10), holidays)  # Queen's Birthday
+        self.assertIn(date(2019, 7, 1), holidays)   # Constitution Day
+        self.assertIn(date(2019, 11, 11), holidays)  # Remembrance Day
+        self.assertIn(date(2019, 12, 25), holidays)  # XMas
+        self.assertIn(date(2019, 12, 26), holidays)  # Boxing Day
+
+    def test_holidays_2020(self):
+        holidays = self.cal.holidays_set(2020)
+        self.assertIn(date(2020, 1, 1), holidays)
+        self.assertIn(date(2020, 1, 27), holidays)  # National Heroes Day
+        self.assertIn(date(2020, 2, 26), holidays)   # Ash Wednesday
+        self.assertIn(date(2020, 4, 10), holidays)  # good friday
+        self.assertIn(date(2020, 4, 13), holidays)  # easter monday
+        self.assertIn(date(2020, 5, 18), holidays)  # Discovery Day
+        self.assertIn(date(2020, 6, 15), holidays)  # Queen's Birthday
+        self.assertIn(date(2020, 7, 6), holidays)   # Constitution Day
+        self.assertIn(date(2020, 11, 9), holidays)  # Remembrance Day
+        self.assertIn(date(2020, 12, 25), holidays)  # XMas
+        self.assertIn(date(2020, 12, 26), holidays)  # Boxing Day
+
+
 class CroatiaTest(GenericCalendarTest):
     cal_class = Croatia
 
@@ -161,7 +311,6 @@ class DenmarkTest(GenericCalendarTest):
     def test_year_2015(self):
         holidays = self.cal.holidays_set(2015)
         self.assertIn(date(2015, 1, 1), holidays)    # nytaarsdag
-        self.assertIn(date(2015, 3, 29), holidays)   # palmesoendag
         self.assertIn(date(2015, 4, 2), holidays)    # skaertaarsdag
         self.assertIn(date(2015, 4, 3), holidays)    # langfredag
         self.assertIn(date(2015, 4, 5), holidays)    # paaskedag
@@ -170,11 +319,9 @@ class DenmarkTest(GenericCalendarTest):
         self.assertIn(date(2015, 5, 14), holidays)   # kristi himmelfart
         self.assertIn(date(2015, 5, 24), holidays)   # pinsedag
         self.assertIn(date(2015, 5, 25), holidays)   # 2. pinsedag
-        self.assertIn(date(2015, 6, 5), holidays)    # grundlovsdag
         self.assertIn(date(2015, 12, 24), holidays)  # juleaftensdag
         self.assertIn(date(2015, 12, 25), holidays)  # juledag
         self.assertIn(date(2015, 12, 26), holidays)  # 2. juledag
-        self.assertIn(date(2015, 12, 31), holidays)  # nytaarsaften
 
 
 class SlovakiaTest(GenericCalendarTest):
@@ -344,17 +491,16 @@ class FranceAlsaceMoselleTest(FranceTest):
     cal_class = FranceAlsaceMoselle
 
     def test_year_2013(self):
-        super(FranceAlsaceMoselleTest, self).test_year_2013()
+        super().test_year_2013()
         holidays = self.cal.holidays_set(2013)
         self.assertIn(date(2013, 3, 29), holidays)  # Good friday
         self.assertIn(date(2013, 12, 26), holidays)  # Boxing day
 
     def test_working_days(self):
-        super(FranceAlsaceMoselleTest, self).test_working_days()
+        super().test_working_days()
 
     def test_business_days_computations(self):
-        super(FranceAlsaceMoselleTest, self) \
-            .test_business_days_computations()
+        super().test_business_days_computations()
 
 
 class GreeceTest(GenericCalendarTest):
@@ -624,6 +770,13 @@ class LuxembourgTest(GenericCalendarTest):
         self.assertIn(date(2016, 12, 25), holidays)  # Christmas
         self.assertIn(date(2016, 12, 26), holidays)  # St. Stephen´s Day
 
+        self.assertNotIn(date(2016, 5, 9), holidays)  # Europe Day (>=2019)
+
+    def test_year_2019(self):
+        holidays = self.cal.holidays_set(2019)
+
+        self.assertIn(date(2019, 5, 9), holidays)   # Europe Day (>=2019)
+
 
 class NetherlandsTest(GenericCalendarTest):
 
@@ -681,6 +834,24 @@ class Romania(GenericCalendarTest):
         self.assertIn(date(2017, 12, 25), holidays)  # Crăciunul Christmas
         self.assertIn(date(2017, 12, 26), holidays)  # Crăciunul Christmas
 
+    def test_year_2019(self):
+        holidays = self.cal.holidays_set(2019)
+        self.assertIn(date(2019, 1, 1), holidays)  # Anul Nou New Year's Day
+        self.assertIn(date(2019, 1, 2), holidays)  # Anul Nou Day after New Yr
+        self.assertIn(date(2019, 1, 24), holidays)  # Unirea Principatelor Rom
+        self.assertIn(date(2019, 4, 26), holidays)  # Orthodox Good Fri
+        self.assertIn(date(2019, 4, 28), holidays)  # Orthodox Easter Sun
+        self.assertIn(date(2019, 4, 29), holidays)  # Orthodox Easter Mon
+        self.assertIn(date(2019, 5, 1), holidays)  # Ziua Muncii Labour Day
+        self.assertIn(date(2019, 6, 1), holidays)  # Ziua Copilului Children's
+        self.assertIn(date(2019, 6, 16), holidays)  # Pentecost
+        self.assertIn(date(2019, 6, 17), holidays)  # Whit Monday
+        self.assertIn(date(2019, 8, 15), holidays)  # Adormirea Maicii Domnului
+        self.assertIn(date(2019, 11, 30), holidays)  # Sfântul Andrei St. Andre
+        self.assertIn(date(2019, 12, 1), holidays)  # Ziua Națională/Marea Unir
+        self.assertIn(date(2019, 12, 25), holidays)  # Crăciunul Christmas
+        self.assertIn(date(2019, 12, 26), holidays)  # Crăciunul Christmas
+
 
 class Russia(GenericCalendarTest):
     cal_class = Russia
@@ -695,12 +866,115 @@ class Russia(GenericCalendarTest):
         self.assertIn(date(2018, 5, 1), holidays)  # Labour Day
         self.assertIn(date(2018, 5, 9), holidays)  # Victory Day
         self.assertIn(date(2018, 6, 12), holidays)  # National Day
-        self.assertIn(date(2018, 11, 5), holidays)  # Day of Unity
+        self.assertIn(date(2018, 11, 4), holidays)  # Independence Day
+
+
+class UkraineTest(GenericCalendarTest):
+    cal_class = Ukraine
+
+    def test_year_1991(self):
+        holidays = self.cal.holidays_set(1991)
+        self.assertIn(date(1991, 6, 16), holidays)  # Independence Day
+        self.assertNotIn(date(1991, 8, 24), holidays)
+
+    def test_year_1992(self):
+        holidays = self.cal.holidays_set(1992)
+        self.assertNotIn(date(1992, 6, 16), holidays)
+        self.assertIn(date(1992, 8, 24), holidays)  # Independence Day
+
+    def test_year_2010(self):
+        holidays = self.cal.holidays_set(2010)
+        self.assertIn(date(2010, 1, 1), holidays)  # New Year's Day
+        self.assertIn(date(2010, 1, 7), holidays)  # Christmas (Orthodox)
+        self.assertIn(date(2010, 3, 8), holidays)  # International Women's Day
+        self.assertIn(date(2010, 5, 1), holidays)  # Workers Solidarity Day
+        self.assertIn(date(2010, 5, 9), holidays)  # Victory Day
+        self.assertIn(date(2010, 5, 24), holidays)  # Whit Monday
+        self.assertIn(date(2010, 6, 28), holidays)  # Constitution Day
+        self.assertIn(date(2010, 8, 24), holidays)  # Independence Day
+
+    def test_year_2015(self):
+        holidays = self.cal.holidays_set(2015)
+        self.assertIn(date(2015, 6, 29), holidays)  # Constitution Day (moved)
+        self.assertIn(date(2015, 10, 14), holidays)  # Defender of Ukraine
+
+    def test_year_2016(self):
+        holidays = self.cal.holidays_set(2016)
+        self.assertIn(date(2016, 1, 1), holidays)  # New Year's Day
+        self.assertIn(date(2016, 1, 7), holidays)  # Christmas (Orthodox)
+        self.assertIn(date(2016, 3, 8), holidays)  # International Women's Day
+        self.assertIn(date(2016, 5, 1), holidays)  # Workers Solidarity Day
+        self.assertIn(date(2016, 5, 2), holidays)  # Workers Solidarity Day
+        self.assertIn(date(2016, 5, 2), holidays)
+        self.assertIn(date(2016, 5, 9), holidays)  # Victory Day
+        self.assertIn(date(2016, 6, 20), holidays)
+        self.assertIn(date(2016, 6, 28), holidays)  # Constitution Day
+        self.assertIn(date(2016, 8, 24), holidays)  # Day of Unity
+        self.assertIn(date(2016, 10, 14), holidays)  # Defender of Ukraine
+        self.assertNotIn(date(2016, 12, 25), holidays)  # Christmas Day
+
+    def test_year_2017(self):
+        holidays = self.cal.holidays_set(2017)
+        self.assertIn(date(2017, 1, 2), holidays)  # New Year's Day (postponed)
+        self.assertIn(date(2017, 1, 9), holidays)  # Christmas Orthodox (moved)
+        self.assertIn(date(2017, 12, 25), holidays)  # Christmas Day
+
+    def test_year_2018(self):
+        holidays = self.cal.holidays_set(2018)
+        self.assertNotIn(date(2018, 5, 2), holidays)  # Workers Solidarity Day
 
 
 class UnitedKingdomTest(GenericCalendarTest):
     cal_class = UnitedKingdom
 
+    def test_year_1973(self):
+        holidays = self.cal.holidays_set(1973)
+        self.assertIn(date(1973, 11, 14), holidays)  # royal wedding
+
+    def test_year_1977(self):
+        holidays = self.cal.holidays_set(1977)
+        self.assertIn(date(1977, 6, 6), holidays)  # Early May Bank Holiday
+        self.assertIn(date(1977, 6, 7), holidays)  # queen's silver jubilee
+
+    def test_year_1981(self):
+        holidays = self.cal.holidays_set(1981)
+        self.assertIn(date(1981, 7, 29), holidays)  # royal wedding
+
+    def test_year_1999(self):
+        holidays = self.cal.holidays_set(1999)
+        self.assertIn(date(1999, 12, 31), holidays)  # new year's eve
+
+    def test_year_2002(self):
+        holidays = self.cal.holidays_set(2002)
+        self.assertIn(date(2002, 1, 1), holidays)  # new year day
+        self.assertIn(date(2002, 3, 29), holidays)  # good friday
+        self.assertIn(date(2002, 3, 31), holidays)  # easter sunday
+        self.assertIn(date(2002, 4, 1), holidays)  # easter monday
+        self.assertIn(date(2002, 5, 6), holidays)  # Early May Bank Holiday
+        self.assertIn(date(2002, 6, 3), holidays)  # queen's golden jubilee
+        self.assertIn(date(2002, 6, 4), holidays)  # Spring Bank Holiday
+        self.assertIn(date(2002, 8, 26), holidays)  # Late Summer Bank Holiday
+        self.assertIn(date(2002, 12, 25), holidays)  # Christmas
+        self.assertIn(date(2002, 12, 26), holidays)  # Boxing Day
+
+    def test_year_2011(self):
+        holidays = self.cal.holidays_set(2011)
+        self.assertIn(date(2011, 4, 29), holidays)  # royal wedding
+
+    def test_year_2012(self):
+        holidays = self.cal.holidays_set(2012)
+        self.assertIn(date(2012, 1, 1), holidays)  # new year day
+        self.assertIn(date(2012, 1, 2), holidays)  # new year shift
+        self.assertIn(date(2012, 4, 6), holidays)  # good friday
+        self.assertIn(date(2012, 4, 8), holidays)  # easter sunday
+        self.assertIn(date(2012, 4, 9), holidays)  # easter monday
+        self.assertIn(date(2012, 5, 7), holidays)  # Early May Bank Holiday
+        self.assertIn(date(2012, 6, 4), holidays)  # Spring Bank Holiday
+        self.assertIn(date(2012, 6, 5), holidays)  # queen's diamond jubilee
+        self.assertIn(date(2012, 8, 27), holidays)  # Late Summer Bank Holiday
+        self.assertIn(date(2012, 12, 25), holidays)  # Christmas
+        self.assertIn(date(2012, 12, 26), holidays)  # Boxing Day
+
     def test_year_2013(self):
         holidays = self.cal.holidays_set(2013)
         self.assertIn(date(2013, 1, 1), holidays)  # new year day
@@ -736,6 +1010,30 @@ class UnitedKingdomTest(GenericCalendarTest):
         self.assertIn(date(2016, 12, 26), holidays)  # Boxing day - Monday
         self.assertIn(date(2016, 12, 27), holidays)  # Christmas - shift to Tue
 
+    def test_2020(self):
+        holidays = self.cal.holidays_set(2020)
+        self.assertIn(date(2020, 1, 1), holidays)  # New Year
+        self.assertIn(date(2020, 4, 10), holidays)  # Good Friday
+        self.assertIn(date(2020, 4, 12), holidays)  # Easter Sunday
+        self.assertIn(date(2020, 4, 13), holidays)  # Easter Monday
+        # This is where the year 2020 becomes special:
+        # The Early May Bank Holiday has been moved to May 8th
+        # to commemorate the 75th anniversary of the end of WWII
+        self.assertNotIn(date(2020, 5, 4), holidays)
+        self.assertIn(date(2020, 5, 25), holidays)  # Spring Bank Holiday
+        self.assertIn(date(2020, 8, 31), holidays)  # Late Summer Bank Holiday
+        self.assertIn(date(2020, 12, 25), holidays)  # Christmas Day
+        self.assertIn(date(2020, 12, 26), holidays)  # 'Boxing Day
+        self.assertIn(date(2020, 12, 28), holidays)  # Boxing Day Shift
+
+        # May the 8th is VE day
+        holidays = self.cal.holidays(2020)
+        holidays = dict(holidays)
+        self.assertIn(date(2020, 5, 8), holidays)
+        self.assertEqual(
+            holidays[date(2020, 5, 8)], "Early May bank holiday (VE day)"
+        )
+
 
 class UnitedKingdomNorthernIrelandTest(UnitedKingdomTest):
     cal_class = UnitedKingdomNorthernIreland
@@ -794,264 +1092,6 @@ class BelgiumTest(GenericCalendarTest):
         self.assertIn(date(2015, 12, 25), holidays)
 
 
-class GermanyTest(GenericCalendarTest):
-    cal_class = Germany
-
-    def test_year_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 1, 1), holidays)
-        self.assertIn(date(2014, 4, 18), holidays)
-        self.assertIn(date(2014, 4, 21), holidays)
-        self.assertIn(date(2014, 5, 1), holidays)
-        self.assertIn(date(2014, 5, 29), holidays)
-        self.assertIn(date(2014, 6, 9), holidays)
-        self.assertIn(date(2014, 10, 3), holidays)
-        self.assertIn(date(2014, 12, 25), holidays)
-        self.assertIn(date(2014, 12, 26), holidays)
-
-    def test_year_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 1, 1), holidays)
-        self.assertIn(date(2015, 4, 3), holidays)
-        self.assertIn(date(2015, 4, 6), holidays)
-        self.assertIn(date(2015, 5, 1), holidays)
-        self.assertIn(date(2015, 5, 14), holidays)
-        self.assertIn(date(2015, 5, 25), holidays)
-        self.assertIn(date(2015, 10, 3), holidays)
-        self.assertIn(date(2015, 12, 25), holidays)
-        self.assertIn(date(2015, 12, 26), holidays)
-
-    def test_year_reformation_day(self):
-        # Reformation Day is included each year in:
-        # Brandenburg, MecklenburgVorpommern, Saxony, SaxonyAnhalt & Thuringia
-        holidays = self.cal.holidays_set(2015)
-        if self.cal.include_reformation_day:
-            self.assertIn(date(2015, 10, 31), holidays)
-        else:
-            self.assertNotIn(date(2015, 10, 31), holidays)
-        # But in the year 2017, it's included for the whole country
-        holidays = self.cal.holidays_set(2017)
-        self.assertIn(date(2017, 10, 31), holidays)
-
-
-class BadenWurttembergTest(GermanyTest):
-    cal_class = BadenWurttemberg
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 1, 6), holidays)
-        self.assertIn(date(2014, 6, 19), holidays)
-        self.assertIn(date(2014, 11, 1), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 1, 6), holidays)
-        self.assertIn(date(2015, 6, 4), holidays)
-        self.assertIn(date(2015, 11, 1), holidays)
-
-
-class BavariaTest(GenericCalendarTest):
-    cal_class = Bavaria
-
-    def test_year_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 1, 1), holidays)
-        self.assertIn(date(2014, 1, 6), holidays)
-        self.assertIn(date(2014, 4, 18), holidays)
-        self.assertIn(date(2014, 4, 21), holidays)
-        self.assertIn(date(2014, 5, 1), holidays)
-        self.assertIn(date(2014, 5, 29), holidays)
-        self.assertIn(date(2014, 6, 9), holidays)
-        self.assertIn(date(2014, 6, 19), holidays)
-        self.assertIn(date(2014, 8, 15), holidays)
-        self.assertIn(date(2014, 10, 3), holidays)
-        self.assertIn(date(2014, 11, 1), holidays)
-        self.assertIn(date(2014, 12, 25), holidays)
-        self.assertIn(date(2014, 12, 26), holidays)
-
-    def test_year_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 1, 1), holidays)
-        self.assertIn(date(2015, 1, 6), holidays)
-        self.assertIn(date(2015, 4, 3), holidays)
-        self.assertIn(date(2015, 4, 6), holidays)
-        self.assertIn(date(2015, 5, 1), holidays)
-        self.assertIn(date(2015, 5, 14), holidays)
-        self.assertIn(date(2015, 5, 25), holidays)
-        self.assertIn(date(2015, 6, 4), holidays)
-        self.assertIn(date(2015, 8, 15), holidays)
-        self.assertIn(date(2015, 10, 3), holidays)
-        self.assertIn(date(2015, 11, 1), holidays)
-        self.assertIn(date(2015, 12, 25), holidays)
-        self.assertIn(date(2015, 12, 26), holidays)
-
-
-class BerlinTest(GermanyTest):
-    cal_class = Berlin
-
-
-class BrandenburgTest(GenericCalendarTest):
-    cal_class = Brandenburg
-
-    def test_year_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 1, 1), holidays)
-        self.assertIn(date(2014, 4, 18), holidays)
-        self.assertIn(date(2014, 4, 20), holidays)
-        self.assertIn(date(2014, 4, 21), holidays)
-        self.assertIn(date(2014, 5, 1), holidays)
-        self.assertIn(date(2014, 5, 29), holidays)
-        self.assertIn(date(2014, 6, 9), holidays)
-        self.assertIn(date(2014, 10, 3), holidays)
-        self.assertIn(date(2014, 10, 31), holidays)
-        self.assertIn(date(2014, 12, 25), holidays)
-        self.assertIn(date(2014, 12, 26), holidays)
-
-    def test_year_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 1, 1), holidays)
-        self.assertIn(date(2015, 4, 3), holidays)
-        self.assertIn(date(2015, 4, 5), holidays)
-        self.assertIn(date(2015, 4, 6), holidays)
-        self.assertIn(date(2015, 5, 1), holidays)
-        self.assertIn(date(2015, 5, 14), holidays)
-        self.assertIn(date(2015, 5, 25), holidays)
-        self.assertIn(date(2015, 10, 3), holidays)
-        self.assertIn(date(2015, 10, 31), holidays)
-        self.assertIn(date(2015, 12, 25), holidays)
-        self.assertIn(date(2015, 12, 26), holidays)
-
-
-class BremenTest(GermanyTest):
-    cal_class = Bremen
-
-
-class HamburgTest(GermanyTest):
-    cal_class = Hamburg
-
-
-class HesseTest(GermanyTest):
-    cal_class = Hesse
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 6, 19), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 6, 4), holidays)
-
-
-class MecklenburgVorpommernTest(GermanyTest):
-    cal_class = MecklenburgVorpommern
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 10, 31), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 10, 31), holidays)
-
-
-class LowerSaxonyTest(GermanyTest):
-    cal_class = LowerSaxony
-
-
-class NorthRhineWestphaliaTest(GermanyTest):
-    cal_class = NorthRhineWestphalia
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 6, 19), holidays)
-        self.assertIn(date(2014, 11, 1), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 6, 4), holidays)
-        self.assertIn(date(2015, 11, 1), holidays)
-
-
-class RhinelandPalatinateTest(GermanyTest):
-    cal_class = RhinelandPalatinate
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 6, 19), holidays)
-        self.assertIn(date(2014, 11, 1), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 6, 4), holidays)
-        self.assertIn(date(2015, 11, 1), holidays)
-
-
-class SaarlandTest(GermanyTest):
-    cal_class = Saarland
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 6, 19), holidays)
-        self.assertIn(date(2014, 8, 15), holidays)
-        self.assertIn(date(2014, 11, 1), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 6, 4), holidays)
-        self.assertIn(date(2015, 8, 15), holidays)
-        self.assertIn(date(2015, 11, 1), holidays)
-
-
-class SaxonyTest(GermanyTest):
-    cal_class = Saxony
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 11, 19), holidays)
-        self.assertIn(date(2014, 10, 31), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 11, 18), holidays)
-        self.assertIn(date(2015, 10, 31), holidays)
-
-    def test_extra_2016(self):
-        holidays = self.cal.holidays_set(2016)
-        self.assertIn(date(2016, 11, 16), holidays)
-        self.assertNotIn(date(2016, 11, 23), holidays)
-        self.assertIn(date(2016, 10, 31), holidays)
-
-
-class SaxonyAnhaltTest(GermanyTest):
-    cal_class = SaxonyAnhalt
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 10, 31), holidays)
-        self.assertIn(date(2014, 1, 6), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 10, 31), holidays)
-        self.assertIn(date(2015, 1, 6), holidays)
-
-
-class SchleswigHolsteinTest(GermanyTest):
-    cal_class = SchleswigHolstein
-
-
-class ThuringiaTest(GermanyTest):
-    cal_class = Thuringia
-
-    def test_extra_2014(self):
-        holidays = self.cal.holidays_set(2014)
-        self.assertIn(date(2014, 10, 31), holidays)
-
-    def test_extra_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 10, 31), holidays)
-
-
 class PortugalTest(GenericCalendarTest):
     cal_class = Portugal
 
@@ -1155,6 +1195,50 @@ class CataloniaTest(GenericCalendarTest):
         self.assertIn(date(2016, 12, 26), holidays)
 
 
+class SerbiaTest(GenericCalendarTest):
+    cal_class = Serbia
+
+    def test_year_2015(self):
+        holidays = self.cal.holidays_set(2015)
+        self.assertIn(date(2015, 1, 1), holidays)
+        self.assertIn(date(2015, 1, 2), holidays)
+        self.assertIn(date(2015, 1, 7), holidays)
+        self.assertIn(date(2015, 2, 15), holidays)
+        self.assertIn(date(2015, 2, 16), holidays)
+        self.assertIn(date(2015, 4, 10), holidays)
+        self.assertIn(date(2015, 4, 12), holidays)
+        self.assertIn(date(2015, 4, 13), holidays)
+        self.assertIn(date(2015, 5, 1), holidays)
+        self.assertIn(date(2015, 5, 2), holidays)
+        self.assertIn(date(2015, 11, 11), holidays)
+
+    def test_year_2016(self):
+        holidays = self.cal.holidays_set(2016)
+        self.assertIn(date(2016, 1, 1), holidays)
+        self.assertIn(date(2016, 1, 2), holidays)
+        self.assertIn(date(2016, 1, 7), holidays)
+        self.assertIn(date(2016, 2, 15), holidays)
+        self.assertIn(date(2016, 2, 16), holidays)
+        self.assertIn(date(2016, 4, 29), holidays)
+        self.assertIn(date(2016, 5, 1), holidays)
+        self.assertIn(date(2016, 5, 2), holidays)
+        self.assertIn(date(2016, 11, 11), holidays)
+
+    def test_year_2017(self):
+        holidays = self.cal.holidays_set(2017)
+        self.assertIn(date(2017, 1, 1), holidays)
+        self.assertIn(date(2017, 1, 2), holidays)
+        self.assertIn(date(2017, 1, 7), holidays)
+        self.assertIn(date(2017, 2, 15), holidays)
+        self.assertIn(date(2017, 2, 16), holidays)
+        self.assertIn(date(2017, 4, 14), holidays)
+        self.assertIn(date(2017, 4, 16), holidays)
+        self.assertIn(date(2017, 4, 17), holidays)
+        self.assertIn(date(2017, 5, 1), holidays)
+        self.assertIn(date(2017, 5, 2), holidays)
+        self.assertIn(date(2017, 11, 11), holidays)
+
+
 class SloveniaTest(GenericCalendarTest):
     cal_class = Slovenia
 
@@ -1268,6 +1352,31 @@ class VaudTest(GenericCalendarTest):
         self.assertNotIn(date(2017, 12, 26), holidays)
 
 
+class GenevaTest(GenericCalendarTest):
+    cal_class = Geneva
+
+    def test_year_2018(self):
+        holidays = self.cal.holidays_set(2018)
+        self.assertIn(date(2018, 9, 6), holidays)
+        self.assertIn(date(2018, 12, 31), holidays)
+        self.assertNotIn(date(2018, 5, 1), holidays)
+        self.assertNotIn(date(2018, 12, 26), holidays)
+
+    def test_year_2019(self):
+        holidays = self.cal.holidays_set(2019)
+        self.assertIn(date(2019, 9, 5), holidays)
+        self.assertIn(date(2019, 12, 31), holidays)
+        self.assertNotIn(date(2019, 5, 1), holidays)
+        self.assertNotIn(date(2019, 12, 26), holidays)
+
+    def test_year_2020(self):
+        holidays = self.cal.holidays_set(2020)
+        self.assertIn(date(2020, 9, 10), holidays)
+        self.assertIn(date(2020, 12, 31), holidays)
+        self.assertNotIn(date(2020, 5, 1), holidays)
+        self.assertNotIn(date(2020, 12, 26), holidays)
+
+
 class EstoniaTest(GenericCalendarTest):
     cal_class = Estonia
 
